@@ -3,6 +3,6 @@ function (x, pre = " ", post = " ", width = 8, ...)
 {
     x <- format(as.vector(x), ...)
     l <- length(x)
-    format(paste(rep(pre, l), x, rep(post, l), sep = ""), width = 10, 
+    format(paste(rep(pre, l), x, rep(post, l), sep = ""), width = width, 
         just = "centre")
 }
